library(testthat)
library(parseRPDR)

testthat::test_check("parseRPDR")
